Field

Struct Field 

pub struct Field {
    pub span: Span,
    pub attr_info: AttrInfo,
    pub name: String,
    pub is_positional: bool,
    pub ty: Ty,
}

Fields

span: Spanattr_info: AttrInfoname: Stringis_positional: bool

Whether this field is positional, as in a tuple struct, tuple variant, or closure. If so, its name is based on its position, such as _0; otherwise, it is a user-provided name.

ty: Ty

Implementations

Source

impl Field

pub fn renamed_name(&self) -> &str

The new name for this field, as suggested by the #[charon::rename] attribute.

pub fn is_opaque(&self) -> bool

Whether this field has a #[charon::opaque] annotation.